===========
mini-ziphmm
===========

.. |ci-status| image:: 	https://img.shields.io/travis/mailund/mini-ziphmm.svg
    :target: https://travis-ci.org/mailund/mini-ziphmm
    :alt: Build status
.. |coveralls| image:: https://img.shields.io/coveralls/mailund/mini-ziphmm.svg
    :target: https://coveralls.io/github/mailund/mini-ziphmm
    :alt: Coverage
.. |versions| image:: 	https://img.shields.io/pypi/v/ziphmm.svg
    :target: https://pypi.python.org/pypi/ziphmm
    :alt: Packgage version
.. |status| image:: https://img.shields.io/pypi/status/ziphmm.svg
    :target: https://pypi.python.org/pypi/ziphmm
    :alt: Package stability


This is a minimal reimplementation of zipHMM in python.
Also contains cython and weave implementations of standard hidden markov models
for comparison.

Undocumented and no install procedure - check test.py for usage

To run:

```bash
make
python test.py
```
